@@ -20,17 +20,16 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 from airflow.providers.common.compat.version_compat import (
-    AIRFLOW_V_2_10_PLUS,
     AIRFLOW_V_3_0_PLUS,
 )
 
 if TYPE_CHECKING:
-    from airflow.api_fastapi.auth.managers.models.resource_details import AssetDetails
+    from airflow.api_fastapi.auth.managers.models.resource_details import AssetAliasDetails, AssetDetails
     from airflow.models.asset import expand_alias_to_assets
     from airflow.sdk.definitions.asset import Asset, AssetAlias, AssetAll, AssetAny
 else:
     if AIRFLOW_V_3_0_PLUS:
-        from airflow.api_fastapi.auth.managers.models.resource_details import AssetDetails
+        from airflow.api_fastapi.auth.managers.models.resource_details import AssetAliasDetails, AssetDetails
         from airflow.models.asset import expand_alias_to_assets
         from airflow.sdk.definitions.asset import Asset, AssetAlias, AssetAll, AssetAny
     else:
@@ -38,20 +37,17 @@ else:
         from airflow.auth.managers.models.resource_details import DatasetDetails as AssetDetails
         from airflow.datasets import (
             Dataset as Asset,
+            DatasetAlias as AssetAlias,
             DatasetAll as AssetAll,
             DatasetAny as AssetAny,
+            expand_alias_to_datasets as expand_alias_to_assets,
         )
 
-        if AIRFLOW_V_2_10_PLUS:
-            from airflow.datasets import (
-                DatasetAlias as AssetAlias,
-                expand_alias_to_datasets as expand_alias_to_assets,
-            )
-
 
 __all__ = [
     "Asset",
     "AssetAlias",
+    "AssetAliasDetails",
     "AssetAll",
     "AssetAny",
     "AssetDetails",
